@@ -1,5 +1,5 @@
 from .deep_image_prior import DeepImagePrior
-from .diffusion import BruteDiffusion, PseudoLinearSampler
+from .diffusion import BruteDiffusion
 from .raw import Raw
 from .jpeg import JPEG
 from .rudalle import BruteRuDalle
